==> satnogs-network-1.89.tar.gz: satnogs-network-1.89/docs/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))
import os
import sys
import time

sys.path.insert(0, os.path.abspath('.'))

import versioneer

__version__ = versioneer.get_versions()['version']
full_revisionid = versioneer.get_versions()['full-revisionid']

del versioneer

# -- Project information -----------------------------------------------------

project = 'SatNOGS Network'
copyright = '2014-{}, Libre Space Foundation'.format(time.strftime('%Y'))
author = 'SatNOGS'
version = __version__
release = __version__

# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ['sphinx.ext.autodoc', 'sphinx.ext.viewcode']
autodoc_default_options = {'members': True, 'private-members': True, 'undoc-members': True}

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

html_context = {
    "display_gitlab": True,
    "gitlab_user": "librespacefoundation",
    "gitlab_repo": "satnogs/satnogs-network",
    "gitlab_version": "master",
    "conf_py_path": "/docs/",
}

if '+' in version:
    api_reference_url = 'https://gitlab.com/{gitlab_user}/{gitlab_repo}/-/jobs/artifacts/{full_revisionid}/file/satnogs-network-api-client/html2/index.html?job=api'.format(
        gitlab_user=html_context['gitlab_user'],
        gitlab_repo=html_context['gitlab_repo'],
        full_revisionid=full_revisionid
    )
else:
    api_reference_url = 'https://{gitlab_user}.gitlab.io/{gitlab_repo}/api/index.html'.format(
        gitlab_user=html_context['gitlab_user'], gitlab_repo=html_context['gitlab_repo']
    )
rst_epilog = """
.. |api_reference_url| replace:: {project} API and SDK Documentation
.. _api_reference_url: {api_reference_url}
""".format(
    project=project, api_reference_url=api_reference_url
)

==> satnogs-network-1.107.tar.gz: satnogs-network-1.107/docs/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))
import os
import sys
import time

sys.path.insert(0, os.path.abspath('.'))

import versioneer

__version__ = versioneer.get_versions()['version']
full_revisionid = versioneer.get_versions()['full-revisionid']

del versioneer

# -- Project information -----------------------------------------------------

project = 'SatNOGS Network'
copyright = '2014-{}, Libre Space Foundation'.format(time.strftime('%Y'))
author = 'SatNOGS'
version = __version__
release = __version__

# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ['sphinx.ext.autodoc', 'sphinx.ext.viewcode']
autodoc_default_options = {'members': True, 'private-members': True, 'undoc-members': True}

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

html_context = {
    "display_gitlab": True,
    "gitlab_user": "librespacefoundation",
    "gitlab_repo": "satnogs/satnogs-network",
    "gitlab_version": "master",
    "conf_py_path": "/docs/",
}

gitlab_user = html_context['gitlab_user']
gitlab_repo = html_context['gitlab_repo']

if '+' in version:
    openapi_yml_url = f'https://gitlab.com/{gitlab_user}/{gitlab_repo}/-/jobs/artifacts/{full_revisionid}/file/satnogs-network-api-client/openapi.yml?job=schema'
    api_reference_url = f'https://gitlab.com/{gitlab_user}/{gitlab_repo}/-/jobs/artifacts/{full_revisionid}/file/satnogs-network-api-client/html2/index.html?job=api'
else:
    openapi_yml_url = f'https://{gitlab_user}.gitlab.io/{gitlab_repo}/api/openapi.yml'
    api_reference_url = f'https://{gitlab_user}.gitlab.io/{gitlab_repo}/api/index.html'

rst_epilog = f"""
.. _SatNOGS Network OpenAPI document: {openapi_yml_url}
.. _interactive API documentation: {api_reference_url}
"""
